#[repr(u8)]pub enum ClosureError {
Physicallyblocked = 0,
Blockedbysensor = 1,
Temperaturelimited = 2,
Maintenancerequired = 3,
Internalinterference = 4,
}Variants
Physicallyblocked = 0
An obstacle is blocking the closure movement
Blockedbysensor = 1
The closure is unsafe to move, as determined by a sensor (e.g. photoelectric sensor) before attempting movement
Temperaturelimited = 2
A warning raised by the closure that indicates an over-temperature, e.g. due to excessive drive or stall current
Maintenancerequired = 3
Some malfunctions that are not easily recoverable are detected, or urgent servicing is needed
Internalinterference = 4
An internal element is prohibiting motion, e.g. an integrated door within a bigger garage door is open and prevents motion
Implementations