#[repr(u8)]pub enum MainState {
Stopped = 0,
Moving = 1,
Waitingformotion = 2,
Error = 3,
Calibrating = 4,
Protected = 5,
Disengaged = 6,
Setuprequired = 7,
}Variants
Stopped = 0
Closure is stopped
Moving = 1
Closure is actively moving
Waitingformotion = 2
Closure is waiting before a motion (e.g. pre-heat, pre-check)
Error = 3
Closure is in an error state
Calibrating = 4
Closure is currently calibrating its Opened and Closed limits to determine effective physical range
Protected = 5
Some protective measures are activated to prevent damage to the closure. Commands MAY be rejected.
Disengaged = 6
Closure has a disengaged element preventing any actuator movements
Setuprequired = 7
Movement commands are ignored since the closure is not operational and requires further setup and/or calibration
Implementations